 # -*- coding: utf-8 -*-
"""
Copyright © 2014 Ford Hurley <ford.hurley@gmail.com>
This work is free. You can redistribute it and/or modify it under the
terms of the Do What The Fuck You Want To Public License, Version 2,
as published by Sam Hocevar. See the COPYING file for more details.
"""

import re

def to_seconds(string):
    """
    Converts a human readable time string into seconds.

    Accepts:
    - 's': seconds
    - 'm': minutes
    - 'h': hours
    - 'd': days

    Examples:
    >>> to_seconds('1m30s')
    90
    >>> to_seconds('5m')
    300
    >>> to_seconds('1h')
    3600
    >>> to_seconds('1h30m')
    5400
    >>> to_seconds('3d')
    259200
    """

    units = {
        's': 1,
        'm': 60,
        'h': 60 * 60,
        'd': 60 * 60 * 24
    }

    match = re.search(r'(?:(?P<d>\d+)d)?(?:(?P<h>\d+)h)?(?:(?P<m>\d+)m)?(?:(?P<s>\d+)s)?', string)

    if match is None:
        raise ValueError

    total = 0
    for unit, seconds in units.iteritems():
        if match.group(unit) is not None:
            total += int(match.group(unit)) * seconds

    return total



 # -*- coding: utf-8 -*-
"""
Copyright © 2014 Ford Hurley <ford.hurley@gmail.com>
This work is free. You can redistribute it and/or modify it under the
terms of the Do What The Fuck You Want To Public License, Version 2,
as published by Sam Hocevar. See the COPYING file for more details.
"""
import urlparse
import boto

def parse_keys(keys):
    """
    Examples:
    >>> parse_keys('accesskey:secretkey')
    ('accesskey', 'secretkey')
    >>> parse_keys('')
    (None, None)
    >>> parse_keys(None)
    (None, None)
    >>> parse_keys('accesskey') # Missing secret key
    Traceback (most recent call last):
        ...
    ValueError: Invalid AWS key string (see the help)
    """
    if keys:
        keys = keys.split(':')
        if len(keys) == 2:
            return tuple(keys)
        else:
            raise ValueError('Invalid AWS key string (see the help)')
    else:
        return None, None


def parse_obj(obj):
    """
    >>> parse_obj('bucket/key')
    ('bucket', 'key')
    >>> parse_obj('my-bucket/path/to/file.txt')
    ('my-bucket', 'path/to/file.txt')
    >>> parse_obj('s3://this_bucket/some/path.txt')
    ('this_bucket', 'some/path.txt')
    >>> parse_obj('https://s3.amazonaws.com/bucket/file.txt')
    ('bucket', 'file.txt')
    >>> parse_obj('http://the-bucket.s3.amazonaws.com/the/file.txt')
    ('the-bucket', 'the/file.txt')
    """
    obj = obj.lstrip('s3://')
    if obj.startswith('http'):
        url = urlparse.urlparse(obj)
        if url.netloc == 's3.amazonaws.com':
            path = url.path[1:]  # remove leading slash
            bucket, key = path.split('/', 1)
        else:
            # bucket.s3.amazonaws.com form
            bucket = url.netloc.split('.', 1)[0]
            key = url.path[1:]
    else:
        bucket, key = obj.split('/', 1)
    return bucket, key


def connect(access_key_id, secret_key):
    return boto.connect_s3(access_key_id, secret_key)


def get_s3_url(conn, bucket_name, key_name, expires_in):
    return conn.generate_url(expires_in=expires_in, method='GET', bucket=bucket_name, key=key_name)
